package com.tencent.mapsdk.vector.demo;

import android.app.Activity;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Toast;

import com.tencent.tencentmap.mapsdk.maps.CameraUpdateFactory;
import com.tencent.tencentmap.mapsdk.maps.MapView;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.CustomLayer;
import com.tencent.tencentmap.mapsdk.maps.model.CustomLayerOptions;
import com.tencent.tencentmap.mapsdk.maps.model.LatLng;

public class CustomLayerActivity extends Activity {
    private CustomLayer mCustomLayer1;
    private CustomLayer mCustomLayer2;

    private boolean mIsMapLoaded = false;
    private boolean mIsLayer1Added;
    private boolean mIsLayer2Added;

    private MapView mapView;
    private TencentMap mTencentMap;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_custom_layer);
        mapView = (MapView) findViewById(R.id.map);
        mTencentMap = mapView.getMap();
        mTencentMap.setOnMapLoadedCallback(new TencentMap.OnMapLoadedCallback() {
            @Override
            public void onMapLoaded() {
                mIsMapLoaded = true;
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        menu.add(0, 0, 0, "添加图层1");
        menu.add(0, 1, 0, "添加图层2");
        menu.add(0, 2, 0, "移除");
        return true;
    }

    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {
        menu.findItem(0).setTitle(mIsLayer1Added ? "查看图层1" : "添加图层1");
        menu.findItem(1).setTitle(mIsLayer2Added ? "查看图层2" : "添加图层2");
        menu.findItem(2).setVisible(mIsLayer1Added || mIsLayer2Added);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        if (!mIsMapLoaded) {
            Toast.makeText(this, "地图还没有准备好", Toast.LENGTH_SHORT).show();
            return true;
        }
        switch (item.getItemId()) {
            case 0:
                if (mCustomLayer1 == null) {
                    mCustomLayer1 = mTencentMap.addCustomLayer(
                            // 清传入自己在 lbs.qq.com 配置的图层 id
                            new CustomLayerOptions().layerId(""));
                }
                if (mCustomLayer1 != null) {
                    if (!mIsLayer1Added) {
                        Toast.makeText(this, "添加图层1成功", Toast.LENGTH_SHORT).show();
                    }
                    mIsLayer1Added = true;
                    mTencentMap.moveCamera(CameraUpdateFactory.newLatLngZoom(new LatLng(19.662432, 109.178696), 15));
                }
                break;
            case 1:
                if (mCustomLayer2 == null) {
                    mCustomLayer2 = mTencentMap.addCustomLayer(
                            // 清传入自己在 lbs.qq.com 配置的图层 id
                            new CustomLayerOptions().layerId(""));
                }
                if (mCustomLayer2 != null) {
                    if (!mIsLayer2Added) {
                        Toast.makeText(this, "添加图层2成功", Toast.LENGTH_SHORT).show();
                    }
                    mIsLayer2Added = true;
                    mTencentMap.moveCamera(CameraUpdateFactory.newLatLngZoom(new LatLng(-35.380093, 138.922119), 13));
                }
                break;
            case 2:
                if (mCustomLayer1 != null) {
                    mCustomLayer1.remove();
                    mCustomLayer1 = null;
                    mIsLayer1Added = false;
                    Toast.makeText(this, "移除图层1成功", Toast.LENGTH_SHORT).show();
                }

                if (mCustomLayer2 != null) {
                    mCustomLayer2.remove();
                    mCustomLayer2 = null;
                    mIsLayer2Added = false;
                    Toast.makeText(this, "移除图层2成功", Toast.LENGTH_SHORT).show();
                }
                break;
        }
        invalidateOptionsMenu();
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (mapView != null) {
            mapView.onResume();
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mapView != null) {
            mapView.onDestroy();
        }
    }
}
