package com.tencent.mapsdk.vector.demo;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

import com.tencent.map.sdk.utilities.heatmap.Gradient;
import com.tencent.map.sdk.utilities.heatmap.HeatMapTileProvider;
import com.tencent.map.sdk.utilities.heatmap.WeightedLatLng;
import com.tencent.tencentmap.mapsdk.maps.SupportMapFragment;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.LatLng;
import com.tencent.tencentmap.mapsdk.maps.model.TileOverlay;
import com.tencent.tencentmap.mapsdk.maps.model.TileOverlayOptions;

import android.graphics.Color;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.Toast;

public class HeatMapActivity extends FragmentActivity {

	/**
	 * Alternative radius for convolution
	 */
	private static final int ALT_HEATMAP_RADIUS = HeatMapTileProvider.DEFAULT_RADIUS;

	/**
	 * Alternative opacity of heatmap overlay
	 */
	private static final double ALT_HEATMAP_OPACITY = HeatMapTileProvider.DEFAULT_OPACITY;

	public static final Gradient ALT_HEATMAP_GRADIENT = HeatMapTileProvider.DEFAULT_GRADIENT;

	private TencentMap tencentMap;
	private TileOverlay heatOverlay;
	private Button btnAddHeatOverlay;
	private Button btnRemoveHeatOverlay;

	private HeatMapTileProvider mProvider;

	@Override
	protected void onCreate(Bundle arg0) {
		// TODO Auto-generated method stub
		super.onCreate(arg0);
		setContentView(R.layout.activity_heat_map);
		init();
	}

	protected void init() {
		FragmentManager fm = getSupportFragmentManager();
		SupportMapFragment mapFragment = 
				(SupportMapFragment) fm.findFragmentById(R.id.frag_map);
		tencentMap = mapFragment.getMap();
		btnAddHeatOverlay = (Button)findViewById(R.id.btn_add_heat_overlay);
		btnRemoveHeatOverlay = (Button)findViewById(R.id.btn_remove_heat_overlay);
		btnAddHeatOverlay.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				// TODO Auto-generated method stub
				if (heatOverlay == null) {
					initHeatMapOverlay();
				} else {
					Toast.makeText(HeatMapActivity.this, 
							"热力图已添加，请等待热力图初始化完成", Toast.LENGTH_SHORT).show();
				}
			}
		});
		btnRemoveHeatOverlay.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				// TODO Auto-generated method stub
				heatOverlay.remove();
				heatOverlay = null;
				Toast.makeText(HeatMapActivity.this, 
						"热力图移除成功", Toast.LENGTH_SHORT).show();
			}
		});
	}

	protected void initHeatMapOverlay() {
		BufferedReader br = null;
		try {
			ArrayList<WeightedLatLng> nodes = new ArrayList<>();
			br = new BufferedReader(new InputStreamReader(
					getResources().getAssets().open("data2k")));
			String line;
			while ((line = br.readLine()) != null) {
				String[] lines = line.split("\t");
				if (lines.length == 3) {
					double value = Double.parseDouble(lines[2]);
					LatLng latLng = new LatLng((Double.parseDouble(lines[1])),
							(Double.parseDouble(lines[0])));
					nodes.add(new WeightedLatLng(latLng, value));
				}
			}

			mProvider = new HeatMapTileProvider.Builder()
					.weightedData(nodes)
					.gradient(ALT_HEATMAP_GRADIENT)
					.opacity(ALT_HEATMAP_OPACITY)
					.radius(ALT_HEATMAP_RADIUS)
					.readyListener(new HeatMapTileProvider.OnHeatMapReadyListener() {
						@Override
						public void onHeatMapReady() {
							heatOverlay.clearTileCache();
							heatOverlay.reload();
						}
					})
					.build();
			heatOverlay = tencentMap.addTileOverlay(new TileOverlayOptions().tileProvider(mProvider));
		} catch (Exception e) {
			e.printStackTrace();
		} finally {
			if (br != null) {
				try {
					br.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}

	}
}
