package com.tencent.mapsdk.vector.demo;

import android.graphics.Color;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.ToggleButton;

import com.tencent.tencentmap.mapsdk.maps.CameraUpdateFactory;
import com.tencent.tencentmap.mapsdk.maps.MapView;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.LatLng;
import com.tencent.tencentmap.mapsdk.maps.model.Polyline;
import com.tencent.tencentmap.mapsdk.maps.model.PolylineOptions;

import java.util.ArrayList;
import java.util.List;

public class LineTextActivity extends FragmentActivity {

    private MapView mMapView;
    private TencentMap mTencentmap;

    private Polyline mPolyline;

    private static List<LatLng> mPoints;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_line_text);
        mMapView = (MapView) findViewById(R.id.map_view);
        mTencentmap = mMapView.getMap();
        mTencentmap.moveCamera(CameraUpdateFactory.zoomTo(16));
        mPoints = new ArrayList<>();
        //苏州街
        mPoints.add(new LatLng(39.982382, 116.305883));
        //北四环西路辅路
        mPoints.add(new LatLng(39.984914, 116.305690));
        //彩和坊路
        mPoints.add(new LatLng(39.985045, 116.308136));
        mPoints.add(new LatLng(39.983570, 116.308088));
        mPoints.add(new LatLng(39.980063, 116.308297));

        ToggleButton tb = findViewById(R.id.tb_change_style);
        tb.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                if (mTencentmap == null
                        || mPolyline == null) {
                    return;
                }
                PolylineOptions.Text text = mPolyline.getText();
                if (text == null) {
                    return;
                }
                if (isChecked) {
                    text.setTextColor(Color.BLACK);
                } else {
                    text.setTextColor(Color.GRAY);
                }
                mPolyline.setText(text);
            }
        });
    }

    public void addLine(View view) {
        if (mTencentmap == null || mPolyline != null) {
            return;
        }
        mPolyline = addLine();
    }

    public void removeLine(View view) {
        if (mPolyline == null) {
            return;
        }
        mPolyline.remove();
        mPolyline = null;
    }

    public Polyline addLine() {
        Polyline polyline = mTencentmap.addPolyline(
                new PolylineOptions()
                        .addAll(mPoints)
                        .color(0x22ff0000));
        return polyline;
    }

    public void addText(View view) {
        if (mTencentmap == null) {
            return;
        }
        if (mPolyline == null) {
            mPolyline = createLineWithText();
        } else {
            mPolyline.setText(createText());
        }
    }

    public void removeText(View view) {
        if (mTencentmap == null || mPolyline == null) {
            return;
        }
        mPolyline.setText(null);
    }

    public Polyline createLineWithText() {
        if (mTencentmap == null) {
            return null;
        }

        Polyline polyline = mTencentmap.addPolyline(
                new PolylineOptions()
                        .addAll(mPoints)
                        .color(0x22ff0000)
                        .text(createText()));
        return polyline;
    }

    public PolylineOptions.Text createText() {
        List<PolylineOptions.SegmentText> segmentTexts = new ArrayList<>();
        segmentTexts.add(new PolylineOptions.SegmentText(0, 1, "苏州街"));
        segmentTexts.add(new PolylineOptions.SegmentText(1, 2, "北四环西路辅路"));
        segmentTexts.add(new PolylineOptions.SegmentText(2, 4, "彩和坊路"));
        return new PolylineOptions.Text.Builder(segmentTexts).build();
    }

    @Override
    protected void onResume() {
        super.onResume();
        mMapView.onResume();
    }

    @Override
    protected void onPause() {
        // TODO Auto-generated method stub
        super.onPause();
        mMapView.onPause();
    }

    @Override
    protected void onDestroy() {
        // TODO Auto-generated method stub
        super.onDestroy();
        mMapView.onDestroy();
    }


    @Override
    protected void onStart() {
        // TODO Auto-generated method stub
        super.onStart();
        mMapView.onStart();
    }

    @Override
    protected void onStop() {
        // TODO Auto-generated method stub
        super.onStop();
        mMapView.onStop();
    }
}
