package com.tencent.mapsdk.vector.demo;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.location.Location;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentManager;
import android.util.Log;
import android.view.View;
import android.widget.ToggleButton;

import com.tencent.map.geolocation.TencentLocation;
import com.tencent.map.geolocation.TencentLocationListener;
import com.tencent.map.geolocation.TencentLocationManager;
import com.tencent.map.geolocation.TencentLocationRequest;
import com.tencent.tencentmap.mapsdk.maps.LocationSource;
import com.tencent.tencentmap.mapsdk.maps.SupportMapFragment;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.BitmapDescriptorFactory;
import com.tencent.tencentmap.mapsdk.maps.model.MyLocationStyle;

public class MapLocationActivity extends FragmentActivity {
	
	private TencentMap tencentMap;
	private DemoLocationSource locationSource;
	
	@Override
	protected void onCreate(Bundle arg0) {
		// TODO Auto-generated method stub
		super.onCreate(arg0);
		setContentView(R.layout.activity_map_location);
		init();
		showLocationSetting();
	}
	
	@Override
	protected void onDestroy() {
		// TODO Auto-generated method stub
		super.onDestroy();
		//这里调用了腾讯定位sdk,如果不再需要定位功能，必须关闭定位。
		if (tencentMap.isMyLocationEnabled()) {
			tencentMap.setMyLocationEnabled(false);
		}
	}
	
	protected void init() {
		FragmentManager fm = getSupportFragmentManager();
		SupportMapFragment mapFragment = 
				(SupportMapFragment)fm.findFragmentById(R.id.frag_map);
		tencentMap = mapFragment.getMap();
		tencentMap.getUiSettings().setZoomControlsEnabled(false);
		
		locationSource = new DemoLocationSource(this);
		tencentMap.setLocationSource(locationSource);
		MyLocationStyle myLocationStyle = new MyLocationStyle();
		myLocationStyle.anchor(0.5f, 0.5f);
		myLocationStyle.icon(BitmapDescriptorFactory.fromResource(R.mipmap.ic_launcher));
		myLocationStyle.myLocationType(MyLocationStyle.LOCATION_TYPE_LOCATION_ROTATE);
		tencentMap.setMyLocationStyle(myLocationStyle);
	}
	
	protected void showLocationSetting() {
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		LocationManager locationManager = (LocationManager) getSystemService(Context.LOCATION_SERVICE);
		if (locationManager.isProviderEnabled(LocationManager.GPS_PROVIDER)) {
			builder.setMessage("GPS is enabled, do you want to change it?");
		} else {
			builder.setMessage("GPS is disabled, do you want to change it?");
		}
		builder.setPositiveButton("Yes", new OnClickListener() {
			
			@Override
			public void onClick(DialogInterface dialog, int which) {
				// TODO Auto-generated method stub
				startActivity(new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS));
				dialog.dismiss();
			}
		});
		builder.setNegativeButton("No", new OnClickListener() {
			
			@Override
			public void onClick(DialogInterface dialog, int which) {
				// TODO Auto-generated method stub
				dialog.dismiss();
			}
		});
		builder.create().show();
	}

	public void switchMyLocation(View view) {
		if (tencentMap == null) {
			return;
		}
		tencentMap.setMyLocationEnabled(((ToggleButton)view).isChecked());
	}
	
	class DemoLocationSource implements LocationSource, TencentLocationListener {

		private OnLocationChangedListener mChangedListener;
		private TencentLocationManager locationManager;
		private TencentLocationRequest locationRequest;
		
		public DemoLocationSource(Context context) {
			// TODO Auto-generated constructor stub
			locationManager = TencentLocationManager.getInstance(context);
			locationRequest = TencentLocationRequest.create();
			locationRequest.setInterval(2000);
		}
		
		@Override
		public void onLocationChanged(TencentLocation arg0, int arg1,
				String arg2) {
			// TODO Auto-generated method stub
			if (arg1 == TencentLocation.ERROR_OK && mChangedListener != null) {
				Log.e("maplocation", "location: " + arg0.getCity() + " " + arg0.getProvider() + " " + arg0.getBearing());
				Location location = new Location(arg0.getProvider());
				location.setLatitude(arg0.getLatitude());
				location.setLongitude(arg0.getLongitude());
				location.setAccuracy(arg0.getAccuracy());
				// 定位 sdk 只有 gps 返回的值才有可能获取到偏向角
				location.setBearing(arg0.getBearing());
				mChangedListener.onLocationChanged(location);
			}
		}

		@Override
		public void onStatusUpdate(String arg0, int arg1, String arg2) {
			// TODO Auto-generated method stub
			
		}

		@Override
		public void activate(OnLocationChangedListener arg0) {
			// TODO Auto-generated method stub
			mChangedListener = arg0;
			int err = locationManager.requestLocationUpdates(locationRequest, this);
			switch (err) {
			case 1:
				setTitle("设备缺少使用腾讯定位服务需要的基本条件");
				break;
			case 2:
				setTitle("manifest 中配置的 key 不正确");
				break;
			case 3:
				setTitle("自动加载libtencentloc.so失败");
				break;

			default:
				break;
			}
		}

		@Override
		public void deactivate() {
			// TODO Auto-generated method stub
			locationManager.removeUpdates(this);
			mChangedListener = null;
		}
	}
}
