package com.tencent.mapsdk.vector.demo;

import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.animation.Animation;
import android.view.animation.Animation.AnimationListener;
import android.view.animation.TranslateAnimation;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.Toast;

import com.tencent.lbssearch.TencentSearch;
import com.tencent.lbssearch.httpresponse.HttpResponseListener;
import com.tencent.lbssearch.object.param.WalkingParam;
import com.tencent.lbssearch.object.result.WalkingResultObject;
import com.tencent.tencentmap.mapsdk.maps.MapView;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.LatLng;
import com.tencent.tencentmap.mapsdk.maps.model.PolylineOptions;

import java.util.List;

public class RoadPlanActivity extends FragmentActivity {

	private ImageView btnWalk;
	private LatLng[] latLngs;
	private TencentMap tencentMap;
	private ListView lvPlans;
	private MapView mapView;
	private RoadPlanAdapter roadPlanAdapter;

	@Override
	protected void onCreate(Bundle arg0) {
		// TODO Auto-generated method stub
		super.onCreate(arg0);
		setContentView(R.layout.activity_road_plan);
		init();
		bindListener();
	}

	protected void init() {
		btnWalk = (ImageView) findViewById(R.id.iv_walk);
		lvPlans = (ListView) findViewById(R.id.lv_plans);
		mapView = (MapView) findViewById(R.id.mapview);
		tencentMap = mapView.getMap();
		roadPlanAdapter = new RoadPlanAdapter(this);
		lvPlans.setAdapter(roadPlanAdapter);
	}

	protected void bindListener() {
		OnClickListener onClickListener = new OnClickListener() {

			@Override
			public void onClick(View v) {
				// TODO Auto-generated method stub
				if (latLngs == null) {
					latLngs = getCoords();
					if (latLngs[0] == null) {
						Toast.makeText(RoadPlanActivity.this,
								"起点坐标不合规则", Toast.LENGTH_LONG).show();
						return;
					}
					if (latLngs[1] == null) {
						Toast.makeText(RoadPlanActivity.this,
								"终点坐标不合规则", Toast.LENGTH_LONG).show();
						return;
					}
				}
				btnWalk.setSelected(false);
				switch (v.getId()) {
					case R.id.iv_walk:
						getWalkPlan();
						Log.e("searchdemo", "walk click");
						btnWalk.setSelected(true);
						break;

					default:
						break;
				}
			}
		};
		btnWalk.setOnClickListener(onClickListener);

		lvPlans.setOnItemClickListener(new OnItemClickListener() {

			@Override
			public void onItemClick(AdapterView<?> parent, View view,
									int position, long id) {
				// TODO Auto-generated method stub
				vanishPlans();
				tencentMap.clear();
				if (roadPlanAdapter.getWalkRoutes() != null) {
					drawSolidLine(roadPlanAdapter.getWalkRoutes().get(position).polyline);
				}
			}
		});
	}

	protected LatLng[] getCoords() {
		LatLng start = new LatLng(39.984154,116.307490);
		LatLng destination = new LatLng(39.882342,116.433106);
		LatLng[] latLngs = {start, destination};
		return latLngs;
	}

	/**
	 * 步行规划，只能设置起点和终点
	 */
	protected void getWalkPlan() {
		TencentSearch tencentSearch = new TencentSearch(this);
		WalkingParam walkingParam = new WalkingParam();
		walkingParam.from(latLngs[0]);
		walkingParam.to(latLngs[1]);
		tencentSearch.getRoutePlan(walkingParam, new HttpResponseListener<WalkingResultObject>() {
			@Override
			public void onSuccess(int statusCode, WalkingResultObject object) {
				if (object == null) {
					return;
				}
				Log.e("searchdemo", "plan success");
				roadPlanAdapter.setWalkRoutes(object);
				roadPlanAdapter.notifyDataSetChanged();
				showPlans();
			}

			@Override
			public void onFailure(int statusCode, String responseString, Throwable throwable) {
				Toast.makeText(RoadPlanActivity.this, responseString, Toast.LENGTH_SHORT).show();
			}
		});
	}


	protected void showPlans() {
		Log.e("searchdemo", "show animatino fonction");
		if (lvPlans.getVisibility() == View.VISIBLE) {
			return;
		}
		TranslateAnimation ta =
				new TranslateAnimation(0, 0, mapView.getBottom(), 0);
		ta.setDuration(200);
		ta.setFillAfter(true);
		ta.setInterpolator(this, android.R.anim.decelerate_interpolator);
		lvPlans.startAnimation(ta);
		lvPlans.setVisibility(View.VISIBLE);
	}

	/**
	 * 将路线以实线画到地图上
	 * @param latLngs
	 */
	protected void drawSolidLine(List<LatLng> latLngs) {
		tencentMap.addPolyline(new PolylineOptions().
				addAll(latLngs).
				color(0xff2200ff));
	}

	protected void vanishPlans() {
		TranslateAnimation ta = new TranslateAnimation(0, 0, 0, mapView.getBottom());
		ta.setDuration(200);
		ta.setFillAfter(true);
		ta.setInterpolator(this, android.R.anim.decelerate_interpolator);
		ta.setAnimationListener(new AnimationListener() {

			@Override
			public void onAnimationStart(Animation animation) {
			}

			@Override
			public void onAnimationRepeat(Animation animation) {
			}

			@Override
			public void onAnimationEnd(Animation animation) {
				lvPlans.setVisibility(View.GONE);
				lvPlans.clearAnimation();
			}
		});
		lvPlans.startAnimation(ta);
	}

	@Override
	protected void onResume() {
		super.onResume();
		mapView.onResume();
	}

	@Override
	protected void onPause() {
		super.onPause();
		mapView.onPause();
	}

	@Override
	protected void onDestroy() {
		super.onDestroy();
		mapView.onDestroy();
	}



	@Override
	protected void onStart() {
		super.onStart();
		mapView.onStart();
	}

	@Override
	protected void onStop() {
		super.onStop();
		mapView.onStop();
	}

}

