package com.tencent.mapsdk.vector.demo;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import com.tencent.lbssearch.object.result.WalkingResultObject;

import java.util.List;

public class RoadPlanAdapter extends BaseAdapter {

	private Context mContext;
	private List<WalkingResultObject.Route> walkRoutes;

	public RoadPlanAdapter(Context context) {
		mContext = context;
	}


	public void setWalkRoutes(WalkingResultObject object){
		walkRoutes = null;
		walkRoutes = object.result.routes;
	}

	public List<WalkingResultObject.Route> getWalkRoutes() {
		return walkRoutes;
	}

	@Override
	public int getCount() {
		int count = 0;
		if (walkRoutes != null) {
			count = walkRoutes.size();
		}
		return count;
	}

	@Override
	public Object getItem(int position) {
		Object obj = null;
		if (walkRoutes != null) {
			obj = walkRoutes.get(position);
		}
		return obj;
	}

	@Override
	public long getItemId(int position) {
		return position;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		ViewHolder viewHolder;
		if (convertView == null) {
			viewHolder = new ViewHolder();
			convertView =
					View.inflate(mContext, R.layout.suggestion_list_item, null);
			viewHolder.label = (TextView) convertView.findViewById(R.id.label);
			viewHolder.desc = (TextView) convertView.findViewById(R.id.desc);
			convertView.setTag(viewHolder);
		} else {
			viewHolder = (ViewHolder) convertView.getTag();
		}
		String strLabel = "";
		String strDesc = "";
		if (walkRoutes != null) {
			WalkingResultObject.Route route = walkRoutes.get(position);
			strLabel = new String("距离：" + getDistance(route.distance) +
					", 预计用时：" + getDuration(route.duration));
			/*
			 * RoutePlanningObject.Step 每段路线的详细信息
			 * 附加描述 accessorial_desc 如“进入主路”
			 * 动作描述 act_desc
			 * 方向 dir_desc
			 * 距离 distance
			 * 用时 duration
			 * 默认提供的路段说明 instruction
			 * 路段点串在总路线点串中的位置 polyline_idx(起点和终点)
			 * 路名 road_name
			 */
			if (route.steps != null && route.steps.size() > 0) {
				strDesc = new String(route.steps.get(0).instruction + "... ...");
			} else {
				strDesc = new String("暂无详情");
			}
		}
		viewHolder.label.setText(strLabel);
		viewHolder.desc.setText(strDesc);
		return convertView;
	}

	class ViewHolder {
		TextView label;
		TextView desc;
	}

	/**
	 * 将距离转换成米或千米
	 * @param distance
	 * @return
	 */
	protected String getDistance(float distance) {
		if (distance < 1000) {
			return Integer.toString((int)distance) + "米";
		} else {
			return Float.toString((float)((int)(distance / 10)) / 100) + "千米";
		}
	}

	/**
	 * 将时间转换成小时+分钟
	 * @param duration
	 * @return
	 */
	protected String getDuration(float duration) {
		if (duration < 60) {
			return Integer.toString((int)duration) + "分钟";
		} else {
			return Integer.toString((int)(duration / 60)) + "小时"
					+ Integer.toString((int)(duration % 60)) + "分钟";
		}
	}
}
