package com.tencent.mapsdk.vector.demo;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.tencent.tencentmap.mapsdk.maps.CameraUpdateFactory;
import com.tencent.tencentmap.mapsdk.maps.MapView;
import com.tencent.tencentmap.mapsdk.maps.TencentMap;
import com.tencent.tencentmap.mapsdk.maps.model.LatLng;
import com.tencent.tencentmap.mapsdk.maps.model.Tile;
import com.tencent.tencentmap.mapsdk.maps.model.TileOverlay;
import com.tencent.tencentmap.mapsdk.maps.model.TileOverlayOptions;
import com.tencent.tencentmap.mapsdk.maps.model.TileProvider;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * Created by wangxiaokun on 2017/1/23.
 */

public class TileOverlayActivity extends Activity implements View.OnClickListener {

    private Button btnAddTileOverlay;
    private Button btnClearTileOverlay;
    private MapView mMapView;
    private TencentMap mTencentMap;
    private TileOverlay mTileOverlay;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_tile_overlay);
        initView();
    }

    protected void initView() {
        mMapView = (MapView)findViewById(R.id.map);
        mTencentMap = mMapView.getMap();
        mTencentMap.moveCamera(CameraUpdateFactory.newLatLngZoom(new LatLng(39.917505,116.397657), 15));

        btnAddTileOverlay = (Button) findViewById(R.id.btn_add_tile_overlay);
        btnClearTileOverlay = (Button) findViewById(R.id.btn_clear_tile_overlay_cache);

        btnAddTileOverlay.setOnClickListener(this);
        btnClearTileOverlay.setOnClickListener(this);
    }

    @Override
    protected void onResume() {
        super.onResume();
        mMapView.onResume();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        mMapView.onDestroy();
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btn_add_tile_overlay:
                if (mTileOverlay == null) {
                    mTileOverlay = mTencentMap.addTileOverlay(
                            new TileOverlayOptions().
                                    tileProvider(new LocalTileProvider()));
                }
                break;
            case R.id.btn_clear_tile_overlay_cache:
                if (mTileOverlay != null) {
                    mTileOverlay.clearTileCache();
                    mTileOverlay.remove();
                    mTileOverlay = null;
                }
                break;
            default:
                break;
        }
    }

    class LocalTileProvider implements TileProvider {

        @Override
        public Tile getTile(int x, int y, int zoom) {
            LatLng latLng = new LatLng(39.917505,116.397657);
            int iZ = 16;
            double n = Math.pow(2, iZ);
            int iX = (int) (((latLng.getLongitude() + 180) / 360) * n);
            int iY = (int) ((1 - (Math.log(Math.tan(Math.toRadians(latLng.getLatitude())) +
                    (1 / Math.cos(Math.toRadians(latLng.getLatitude())))) / Math.PI)) / 2 * n);
            if (iX == x && iY == y && iZ == zoom) {
                Log.e("tile", "zoom:" + zoom + " x:" + x + " y:" + y);
                return new Tile(256, 256, tileData());
            }
            return TileProvider.NO_TILE;
        }

        byte[] tileData() {
            InputStream is = null;
            ByteArrayOutputStream baos = null;
            try {
                is = getApplicationContext().getAssets().open("tile.jpg");
                baos = new ByteArrayOutputStream();
                byte[] byteBuffer = new byte[1024];
                int count = 0;
                while ((count = is.read(byteBuffer)) != -1) {
                    baos.write(byteBuffer, 0, count);
                }
                return baos.toByteArray();
            } catch (IOException e) {
                e.printStackTrace();
                return null;
            } finally {
                if (is != null) {
                    try {
                        is.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
                if (baos != null) {
                    try {
                        baos.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }
}
